@echo off
rem ============================================================================
rem @file   prelink.bat
rem
rem @path   $(DSPLINK)/etc/host/projects/WinCE/DSPLink/
rem
rem @desc   Sets the dsplink environment and builds DSPLINK binaries. This 
rem         file is used by the platform builder to build the DSPLINK subproject.
rem
rem @ver    1.65.02.09
rem ============================================================================
rem Copyright (C) 2002-2012, Texas Instruments Incorporated -
rem http://www.ti.com/
rem
rem Redistribution and use in source and binary forms, with or without
rem modification, are permitted provided that the following conditions
rem are met:
rem 
rem *  Redistributions of source code must retain the above copyright
rem    notice, this list of conditions and the following disclaimer.
rem 
rem *  Redistributions in binary form must reproduce the above copyright
rem    notice, this list of conditions and the following disclaimer in the
rem    documentation and/or other materials provided with the distribution.
rem 
rem *  Neither the name of Texas Instruments Incorporated nor the names of
rem    its contributors may be used to endorse or promote products derived
rem    from this software without specific prior written permission.
rem 
rem THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
rem AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
rem THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
rem PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR
rem CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
rem EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
rem PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
rem OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
rem WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
rem OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE,
rem EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
rem ============================================================================

@REM Add pre-link commands below.



@if not [%SYSGEN_DSPLINK%] == [1] goto:EOF
@rem *************************************************************************************************
@rem * For some unknown reason, PB converts all environment variable names from mixed case to lower case
@rem * So this a simple batch trick to convert them (only relevant to dsplink) back to desired mixed case
@rem * which gmake expects
@rem *************************************************************************************************



@rem create the list of variable names. The desired mixed case format name followed by the lower case format name
@set VAR_NAMES_SET=_WINCEROOT _winceroot _PROJECTROOT _projectroot _TGTCPU _tgtcpu _TARGETPLATROOT _targetplatroot 
@set VAR_NAMES_SET=%VAR_NAMES_SET% _FLATRELEASEDIR _flatreleasedir WINCEDEBUG wincedebug ComSpec comspec TEMP temp
@set VAR_NAMES_SET=%VAR_NAMES_SET% TI_TOOLS_BASE_DIR ti_tools_base_dir XDC_INSTALL_DIR xdc_install_dir PATH path 

@set VAR_NAMES_SET=%VAR_NAMES_SET% BIOS_INSTALL_DIR bios_install_dir BASE_PERL base_perl CODEGEN_INSTALL_DIR codegen_install_dir
@call :Loop4 %VAR_NAMES_SET%
@goto start_build


@rem this loop just processes the variables in VAR_NAMES_SET one set (pair) at a time

:Loop4
@if [%1]==[] goto:EOF
@call set my_temp=%%%2%%
@set %2=
@set %1=%my_temp%
@shift
@shift
@goto Loop4

:start_build
@set VAR_NAMES_SET=
@set my_temp=
rem ----------------------------------------------------------------------------
rem @name   DSPLINK
rem
rem @desc   Root directory of DSP/BIOS LINK.
rem ----------------------------------------------------------------------------
set CURR_PATH=%CD%
set DSPLINK=%CURR_PATH:\etc\host\projects\WinCE\DSPLink=%


rem ----------------------------------------------------------------------------
rem @name   PATH
rem
rem @desc   Appends the path to the host scripts
rem ----------------------------------------------------------------------------
set PERL_BIN_PATH=C:\Perl\bin
if not [%BASE_PERL%]==[] set PERL_BIN_PATH=%BASE_PERL%\bin
set PATH=%PATH%;%DSPLINK%\etc\host\scripts\msdos;%PERL_BIN_PATH%

echo ===========================================================

echo The environment for DSP/BIOS LINK development has been set:
echo DSPLINK  = %DSPLINK%
echo PATH    += %DSPLINK%\etc\host\scripts\msdos;%PERL_BIN_PATH%
echo ===========================================================

set PERL_BIN_PATH=



rem ----------------------------------------------------------------------------

rem @name   SETPATHS_BAT

rem

rem @desc   Look for setpaths.bat, if present

rem ----------------------------------------------------------------------------

set SETPATHS_BAT=%DSPLINK%\..\..\setpaths.bat

if exist %SETPATHS_BAT% call %SETPATHS_BAT%

set SETPATHS_BAT=



cd %DSPLINK%\etc\host\scripts\msdos
call dsplinkcfg.bat %CFG_DSPLINK_STR%
cd %DSPLINK%



echo ===========================================================
echo Starting ARM build
echo ===========================================================
%XDC_INSTALL_DIR%/gmake -C gpp/src -f Makefile -s release
echo ===========================================================
echo Starting ARM sample application build
echo ===========================================================
%XDC_INSTALL_DIR%/gmake -C gpp/src/samples/message -f Makefile -s release 
echo ===========================================================
echo Starting DSP build
echo ===========================================================
%XDC_INSTALL_DIR%/gmake -C dsp/src -f Makefile -s release 
echo ===========================================================
echo Starting DSP sample application build
echo ===========================================================
%XDC_INSTALL_DIR%/gmake -C dsp/src/samples/message -f Makefile -s release 

cd  %DSPLINK%/gpp
%XDC_INSTALL_DIR%/xdc clean
%XDC_INSTALL_DIR%/xdc .interfaces

cd  %DSPLINK%/dsp
%XDC_INSTALL_DIR%/xdc clean
%XDC_INSTALL_DIR%/xdc .interfaces

cd %_WINCEROOT%
