#!/usr/bin/perl
#   ============================================================================
#   @file   recdir.pl
#
#   @path   $(DSPLINK)/etc/host/tools/PrOS/Jacinto/
#
#   @desc   Change the names of executable and test files to comply with 8.3
#           format supported by PrFile.
#
#   @ver    1.65.02.09
#   ============================================================================
#   Copyright (C) 2002-2012, Texas Instruments Incorporated -
#   http://www.ti.com/
#
#   Redistribution and use in source and binary forms, with or without
#   modification, are permitted provided that the following conditions
#   are met:
#   
#   *  Redistributions of source code must retain the above copyright
#      notice, this list of conditions and the following disclaimer.
#   
#   *  Redistributions in binary form must reproduce the above copyright
#      notice, this list of conditions and the following disclaimer in the
#      documentation and/or other materials provided with the distribution.
#   
#   *  Neither the name of Texas Instruments Incorporated nor the names of
#      its contributors may be used to endorse or promote products derived
#      from this software without specific prior written permission.
#   
#   THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
#   AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
#   THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
#   PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR
#   CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
#   EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
#   PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
#   OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
#   WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
#   OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE,
#   EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
#   ============================================================================

#  *****************************************************************************
#  * USAGE :                                                                   *
#  *                                                                           *
#  * recdir.pl path                                                            *
#  *****************************************************************************

$debug = 1 ;

$slash = '\\' ;

#  =============================================================================
#  Parse command line parameters
#  =============================================================================

if ($#ARGV < 0)
{
    die "USAGE : [PERL] recdir.pl path [outfile]\n" ;
}

$upath  = $ARGV [0] ;

if ($debug == 1)
{
    print "Listing directory : $upath\n"  ;
}


if ($#ARGV == 1)
{
    $outfile = $ARGV [1] ;
    if ($debug == 1)
    {
        print "Writing to file   : $outfile\n"  ;
    }
}
else
{
    $outfile = '' ;
}

print "\n" ;

#  =============================================================================
#  Create the list of elements in source directory
#  =============================================================================

if ($outfile ne '')
{
    open (OUTFILE, ">$outfile")  || die "!!ERROR!! Couldn't open $outfile\n" ;

    if (-e $upath)
    {
        &ListDirectory ($upath, OUTFILE) ;
    }

    close (OUTFILE) ;
}
else
{
    if (-e $upath)
    {
        &ListDirectory ($upath, 'TERMINAL') ;
    }
}

#  =============================================================================
#  Done!!
#  =============================================================================

exit (0) ;


#  =============================================================================
#  sub  ListDirectory
#  =============================================================================

sub ListDirectory
{
    local ($path) = shift (@_) ;
    local ($out)  = @_ ;
    local (@dirs) = () ;

    push (@dirs, $path) ;           # add an element to an array

    foreach $dir (@dirs)            # loop through the elements of an array
    {
        local (@list) = () ;

        opendir (DIR,"$dir") || die "Couldn't open $dir\n" ;

        @list = grep (!/^\.\.?$/, readdir (DIR)) ;

        closedir (DIR) ;

        foreach $item (@list)
        {
            local ($name) = $dir . $slash . $item ;

            if (-d $name)
            {
                push(@dirs, $name) ;

                if ($out eq 'TERMINAL')
                {
                    print "D $name\n" ;
                }
                else
                {
                    print $out "D $name\n" ;
                }
            }
            elsif (-f $name)
            {
                if ($out eq 'TERMINAL')
                {
                    print "F $name\n" ;
                }
                else
                {
                    print $out "F $name\n" ;
                }
            }
            else
            {
                print "What's this? : $name\n";
            }
        }
    }
}
