/** ============================================================================
 *  @file   print.c
 *
 *  @path   $(DSPLINK)/gpp/src/osal/PrOS/
 *
 *  @desc   Implementation of OS printf abstraction.
 *
 *  @ver    1.65.02.09
 *  ============================================================================
 *  Copyright (C) 2002-2012, Texas Instruments Incorporated -
 *  http://www.ti.com/
 *
 *  Redistribution and use in source and binary forms, with or without
 *  modification, are permitted provided that the following conditions
 *  are met:
 *  
 *  *  Redistributions of source code must retain the above copyright
 *     notice, this list of conditions and the following disclaimer.
 *  
 *  *  Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  
 *  *  Neither the name of Texas Instruments Incorporated nor the names of
 *     its contributors may be used to endorse or promote products derived
 *     from this software without specific prior written permission.
 *  
 *  THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 *  AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 *  THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 *  PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR
 *  CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 *  EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 *  PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 *  OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 *  WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 *  OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE,
 *  EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 *  ============================================================================
 */


/*  ----------------------------------- OS Specific Headers         */
#include <itron.h>
#include <stdio.h>
#include <stdarg.h>

/*  ----------------------------------- DSP/BIOS Link               */
#include <dsplink.h>
#include <_dsplink.h>

/*  ----------------------------------- OSAL Headers                */
#include <osal.h>


#if defined (__cplusplus)
extern "C" {
#endif /* defined (__cplusplus) */


/** ============================================================================
 *  @func   kprintf
 *
 *  @desc   Extern declaration for kprintf function to avoid compiler warning.
 *
 *  @arg    str
 *              String representation of the number.
 *  @arg    ...
 *              Variable arguments.
 *
 *  @ret    None
 *
 *  @enter  None
 *
 *  @leave  None
 *
 *  @see    None
 *  ============================================================================
 */
#if !defined (DRX45X)
extern void kprintf (char* fp, ... ) ;

/** ============================================================================
 *  @func   pspUartConsoleOut
 *
 *  @desc   Extern declaration for uart console out function .
 *
 *  ============================================================================
 */
extern void pspUartConsoleOut(Int data);
#endif /* !defined (DRX45X) */

/** ============================================================================
 *  @func   PRINT_Initialize
 *
 *  @desc   Initializes the PRINT sub-component.
 *
 *  @modif  None
 *  ============================================================================
 */
EXPORT_API
DSP_STATUS
PRINT_Initialize ()
{
    return DSP_SOK ;
}


/** ============================================================================
 *  @func   PRINT_Finalize
 *
 *  @desc   Releases resources used this sub-component.
 *
 *  @modif  None
 *  ============================================================================
 */
EXPORT_API
DSP_STATUS
PRINT_Finalize ()
{
    return DSP_SOK ;
}


/** ============================================================================
 *  @func   PRINT_Printf
 *
 *  @desc   Provides standard printf functionality abstraction.
 *
 *  @modif  None
 *  ============================================================================
 */
EXPORT_API
Void
PRINT_Printf (Pstr format, ...)
{
    INT arg1, arg2, arg3, arg4, arg5, arg6 ;
    va_list va ;

    /*Check if pspUartConsoleOut console out function is
     *initialized  to call kprintf
     */
#if !defined (DRX45X)
    if (&pspUartConsoleOut != NULL) {

        va_start (va, format) ;

        arg1 = va_arg (va, INT) ;
        arg2 = va_arg (va, INT) ;
        arg3 = va_arg (va, INT) ;
        arg4 = va_arg (va, INT) ;
        arg5 = va_arg (va, INT) ;
        arg6 = va_arg (va, INT) ;

        va_end (va) ;

        kprintf (format, arg1, arg2, arg3, arg4, arg5, arg6) ;
    }
#else /* defined (DRX45X) */
    va_start (va, format) ;

    arg1 = va_arg (va, INT) ;
    arg2 = va_arg (va, INT) ;
    arg3 = va_arg (va, INT) ;
    arg4 = va_arg (va, INT) ;
    arg5 = va_arg (va, INT) ;
    arg6 = va_arg (va, INT) ;

    va_end (va) ;

    printf (format, arg1, arg2, arg3, arg4, arg5, arg6) ;
#endif /* !defined (DRX45X) */
}


#if defined (__cplusplus)
}
#endif /* defined (__cplusplus) */
