/** ============================================================================
 *  @file   user.c
 *
 *  @path   $(DSPLINK)/gpp/src/osal/WinCE/
 *
 *  @desc   Implementation of user access.
 *
 *  @ver    1.65.02.09
 *  ============================================================================
 *  Copyright (C) 2002-2012, Texas Instruments Incorporated -
 *  http://www.ti.com/
 *
 *  Redistribution and use in source and binary forms, with or without
 *  modification, are permitted provided that the following conditions
 *  are met:
 *  
 *  *  Redistributions of source code must retain the above copyright
 *     notice, this list of conditions and the following disclaimer.
 *  
 *  *  Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  
 *  *  Neither the name of Texas Instruments Incorporated nor the names of
 *     its contributors may be used to endorse or promote products derived
 *     from this software without specific prior written permission.
 *  
 *  THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 *  AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 *  THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 *  PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR
 *  CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 *  EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 *  PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 *  OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 *  WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 *  OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE,
 *  EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 *  ============================================================================
 */


/*  ----------------------------------- OS Specific Headers         */
#include <windows.h>
#include <pkfuncs.h> 

/*  ----------------------------------- DSP/BIOS Link               */
#include <dsplink.h>
#include <_dsplink.h>

/*  ----------------------------------- Trace & Debug               */
#include <_trace.h>
#include <trc.h>
#include <print.h>

/*  ----------------------------------- OSAL Headers                */
#include <osal.h>


#if defined (__cplusplus)
extern "C" {
#endif /* defined (__cplusplus) */


/** ============================================================================
 *  @macro  COMPONENT_ID
 *
 *  @desc   Identifier for sub-component.
 *  ============================================================================
 */
#define COMPONENT_ID        ID_OSAL_USER

/** ============================================================================
 *  @macro  SET_FAILURE_REASON
 *
 *  @desc   Sets failure reason.
 *  ============================================================================
 */
#if defined (DDSP_DEBUG)
#define SET_FAILURE_REASON   TRC_SetReason (status, FID_C_OSAL_USER, __LINE__)
#else
#define SET_FAILURE_REASON
#endif /* if defined (DDSP_DEBUG) */

/** ============================================================================
 *  @func   USER_copyFromUser
 *
 *  @desc   Copy user data to kernel buffer.
 *
 *  @modif  None
 *  ============================================================================
 */
EXPORT_API
DSP_STATUS
USER_copyFromUser (OUT Pvoid dst, IN Pvoid src, IN Uint32 numBytes)
{
    DSP_STATUS  status = DSP_SOK ;
    Uint32      copied = 0       ;
    HRESULT     osStatus;
    PVOID       mappedPtr = NULL;

    TRC_3ENTER ("USER_copyFromUser", dst, src, numBytes) ;

    DBC_Require (src != NULL) ;
    DBC_Require (dst != NULL) ;

    
    osStatus = CeOpenCallerBuffer((PVOID*)&mappedPtr, (LPVOID)src, numBytes,ARG_I_PTR, FALSE);
    if (osStatus == S_OK)
    {
        memcpy(dst, mappedPtr, numBytes) ;    
        CeCloseCallerBuffer((PVOID)mappedPtr, (LPVOID)src, numBytes,ARG_I_PTR);        
    }
    else {
        status = DSP_EFAIL ;
        SET_FAILURE_REASON ;
    }

    TRC_1LEAVE ("USER_copyFromUser", status) ;

    return status ;
}


/** ============================================================================
 *  @func   USER_copyTOUser
 *
 *  @desc   Copy kernel data to user buffer.
 *
 *  @modif  None
 *  ============================================================================
 */
EXPORT_API
DSP_STATUS
USER_copyToUser (IN Pvoid src, OUT Pvoid dst, IN Uint32 numBytes)
{
    DSP_STATUS  status = DSP_SOK ;
    Uint32      copied = 0       ;
    HRESULT     osStatus;            
    PVOID       mappedPtr = NULL;

    TRC_3ENTER ("USER_copyToUser", src, dst, numBytes) ;

    DBC_Require (src != NULL) ;
    DBC_Require (dst != NULL) ;

    osStatus = CeOpenCallerBuffer((PVOID*)&mappedPtr, (LPVOID)dst, numBytes,ARG_O_PTR, FALSE);
    if (osStatus == S_OK)
    {
        memcpy(mappedPtr, src, numBytes) ;    
        CeCloseCallerBuffer((PVOID)mappedPtr, (LPVOID)src, numBytes,ARG_O_PTR);        
    }
    else {
        status = DSP_EFAIL ;
        SET_FAILURE_REASON ;
    }

    TRC_0LEAVE ("USER_copyToUser") ;

    return status ;
}


#if defined (__cplusplus)
}
#endif /* defined (__cplusplus) */
